==> haskell-pointed-5.0.5-119.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-F62LVAgvv9AGSTClAwEX2m
key:                  pointed-5.0.5-F62LVAgvv9AGSTClAwEX2m
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  8546eb7bc96d4a1097249b8c4ab5f033
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-F62LVAgvv9AGSTClAwEX2m
depends:
    base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    kan-extensions-5.2.7-EnBT78A8Pv5AQm9RtrTyNw
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.5-120-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-G4KDyoxPFVpBOfflLbnKHj
key:                  pointed-5.0.5-G4KDyoxPFVpBOfflLbnKHj
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  fe9de4a19384bfd6a9e402991fd2fed5
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-G4KDyoxPFVpBOfflLbnKHj
depends:
    base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    kan-extensions-5.2.7-CxNd8hhXH2ZC3bz6YYdu9A
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
